@@ -365,7 +365,7 @@ void K3b::MainWindow::initActions()
     actionFileNewMenu->setIcon( QIcon::fromTheme( "document-new" ) );
     actionFileNewMenu->setToolTip(i18n("Creates a new project"));
     actionFileNewMenu->setStatusTip( actionFileNewMenu->toolTip() );
-    actionFileNewMenu->setDelayed( false );
+    actionFileNewMenu->setPopupMode( QToolButton::InstantPopup );
     actionFileNewMenu->addAction( actionFileNewData );
     actionFileNewMenu->addAction( actionFileContinueMultisession );
     actionFileNewMenu->addSeparator();
@@ -460,7 +460,7 @@ QList<K3b::Doc*> K3b::MainWindow::projects() const
 
 void K3b::MainWindow::slotConfigureKeys()
 {
-    KShortcutsDialog::configure( actionCollection(),KShortcutsEditor::LetterShortcutsDisallowed, this );
+    KShortcutsDialog::showDialog( actionCollection(), KShortcutsEditor::LetterShortcutsDisallowed, this );
 }
 
 void K3b::MainWindow::initStatusBar()
@@ -756,8 +756,8 @@ void K3b::MainWindow::readProperties( const KConfigGroup& grp )
 
     int cnt = grp.readEntry( "Number of projects", 0 );
 /*
-  qDebug() << "(K3b::MainWindow::readProperties) number of projects from last session in " << saveDir << ": " << cnt << endl
-  << "                                read from config group " << c->group() << endl;
+  qDebug() << "(K3b::MainWindow::readProperties) number of projects from last session in " << saveDir << ": " << cnt << Qt::endl
+  << "                                read from config group " << c->group() << Qt::endl;
 */
     for( int i = 1; i <= cnt; ++i ) {
         // in this case the constructor works since we saved as url()
@@ -892,10 +892,10 @@ bool K3b::MainWindow::canCloseDocument( K3b::Doc* doc )
         return true;
 
     switch ( KMessageBox::warningYesNoCancel( this,
-                                              i18n("%1 has unsaved data.", doc->URL().fileName() ),
+                                              xi18nc("@info", "Project <resource>%1</resource> has unsaved data.", doc->URL().fileName() ),
                                               i18n("Closing Project"),
                                               KStandardGuiItem::save(),
-                                              KStandardGuiItem::dontSave() ) ) {
+                                              KStandardGuiItem::discard() ) ) {
     case KMessageBox::Yes:
         return fileSave( doc );
     case KMessageBox::No:
