@@ -1,17 +1,7 @@
 /*
- *
- * Copyright (C) 2003-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
-
+    SPDX-FileCopyrightText: 1998-2009 Sebastian Trueg <trueg@k3b.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3baudioburndialog.h"
 #include "k3baudioview.h"
@@ -220,9 +210,10 @@ void K3b::AudioBurnDialog::toggleAll()
 
     bool cdrecordOnTheFly = false;
     bool cdrecordCdText = false;
-    if ( k3bcore->externalBinManager()->binObject("cdrecord") ) {
-        cdrecordOnTheFly = k3bcore->externalBinManager()->binObject("cdrecord")->hasFeature( "audio-stdin" );
-        cdrecordCdText = k3bcore->externalBinManager()->binObject("cdrecord")->hasFeature( "cdtext" );
+    const K3b::ExternalBin* cdrecordBin = k3bcore->externalBinManager()->binObject("cdrecord");
+    if ( cdrecordBin ) {
+        cdrecordOnTheFly = cdrecordBin->hasFeature( "audio-stdin" );
+        cdrecordCdText = cdrecordBin->hasFeature( "cdtext" );
     }
 
     // cdrdao always knows onthefly and cdtext
